.. -*- coding: utf-8; -*-

============
 mqbeebotte
============

Unofficial `Beebotte <https://beebotte.com/>`_ MQTT access package.

Required Packages
=================

* paho-mqtt

How to Install?
===============

Run ``pip install mqbeebotte``.

How to Use?
===========

See sample codes in `sample directory <https://github.com/pman0214/mqbeebotte/tree/master/sample>`_.

Currently, this package only provides client subscribe/publish methods.

Copyright, License
==================

Copyright (c) 2020, Shigemi ISHIDA

* This package is released under the BSD 3-clause license. See ``LICENSE.txt``.
* Sample source codes are released under the MIT license.  See ``sample/LICENSE_MIT.txt``.
